@@ -10,7 +10,7 @@ import datetime
 import logging
 from pathlib import Path
 import sys
-import cchardet as chardet
+from  charset_normalizer import detect
 from . import normalizer
 from . import metadata
 
@@ -41,6 +41,7 @@ def _parse_line(block, line):
     try:
         if not line.strip():
             return {}
+        line = line.rstrip(',')
         return {k:_conv(block, k, v)
                 for k, v in (i.split("=", 1) if "=" in i else [i[0], i[1:]]
                              for i in re.split(_RE_FIELD_SEP, line) if i)}
@@ -58,7 +59,7 @@ def _parse_raw(input_filename, *arg, **kw):
 def _parse_raw_from_file(f, encoding=None):
     if encoding is None:
         sample = f.read(4096)
-        detection = chardet.detect(sample)
+        detection = detect(sample)
         if detection["confidence"] < 0.85:
             encoding = 'latin-1'
         else:
@@ -78,8 +79,11 @@ def _parse_raw_from_file(f, encoding=None):
             sections.append(blocks)
         if row in ("£", "$", "#", "€", "#$"):
             block = row
-        elif block in blocks:
-            blocks[block].append(_parse_line(metadata.blocknames[block], row))
+        else:
+            if blocks is None:
+                raise ValueError("First block is not a main block")
+            if block in blocks:
+                blocks[block].append(_parse_line(metadata.blocknames[block], row))
     return sections
 
 def _rename_blocks(sections):
